@@ -904,6 +904,10 @@ var testExpr = []struct {
 		// TODO(fabxc): willingly lexing wrong tokens allows for more precrise error
 		// messages from the parser - consider if this is an option.
 		errMsg: "unexpected character inside braces: '>'",
+	}, {
+		input:  "some_metric{a=\"\xff\"}",
+		fail:   true,
+		errMsg: "parse error at char 15: invalid UTF-8 rune",
 	}, {
 		input:  `foo{gibberish}`,
 		fail:   true,
@@ -1356,11 +1360,11 @@ var testExpr = []struct {
 	}, {
 		input:  "floor()",
 		fail:   true,
-		errMsg: "expected at least 1 argument(s) in call to \"floor\", got 0",
+		errMsg: "expected 1 argument(s) in call to \"floor\", got 0",
 	}, {
 		input:  "floor(some_metric, other_metric)",
 		fail:   true,
-		errMsg: "expected at most 1 argument(s) in call to \"floor\", got 2",
+		errMsg: "expected 1 argument(s) in call to \"floor\", got 2",
 	}, {
 		input:  "floor(1)",
 		fail:   true,
@@ -1373,6 +1377,10 @@ var testExpr = []struct {
 		input:  "rate(some_metric)",
 		fail:   true,
 		errMsg: "expected type range vector in call to function \"rate\", got instant vector",
+	}, {
+		input:  "label_replace(a, `b`, `c\xff`, `d`, `.*`)",
+		fail:   true,
+		errMsg: "parse error at char 23: invalid UTF-8 rune",
 	},
 	// Fuzzing regression tests.
 	{
