@@ -14,6 +14,7 @@
 package remote
 
 import (
+	"fmt"
 	"sync"
 	"time"
 
@@ -36,10 +37,10 @@ type Reader struct {
 func (r *Reader) ApplyConfig(conf *config.Config) error {
 	clients := []*Client{}
 	for i, rrConf := range conf.RemoteReadConfigs {
-		c, err := NewClient(i, &clientConfig{
-			url:              rrConf.URL,
-			timeout:          rrConf.RemoteTimeout,
-			httpClientConfig: rrConf.HTTPClientConfig,
+		c, err := NewClient(i, &ClientConfig{
+			URL:              rrConf.URL,
+			Timeout:          rrConf.RemoteTimeout,
+			HTTPClientConfig: rrConf.HTTPClientConfig,
 		})
 		if err != nil {
 			return err
@@ -93,11 +94,33 @@ func (q *querier) read(ctx context.Context, from, through model.Time, matchers m
 	if err != nil {
 		return nil, err
 	}
-
 	removeLabels(res, added)
+	err = validateLabelsAndMetricName(res)
+	if err != nil {
+		return nil, err
+	}
+
 	return res, err
 }
 
+// validateLabelsAndMetricName validates the label names/values and metric names returned from remote read.
+func validateLabelsAndMetricName(res model.Matrix) error {
+	for _, r := range res {
+		if !model.IsValidMetricName(r.Metric[model.MetricNameLabel]) {
+			return fmt.Errorf("Invalid metric name: %v", r.Metric[model.MetricNameLabel])
+		}
+		for name, value := range r.Metric {
+			if !name.IsValid() {
+				return fmt.Errorf("Invalid label name: %v", name)
+			}
+			if !value.IsValid() {
+				return fmt.Errorf("Invalid label value: %v", value)
+			}
+		}
+	}
+	return nil
+}
+
 // addExternalLabels adds matchers for each external label. External labels
 // that already have a corresponding user-supplied matcher are skipped, as we
 // assume that the user explicitly wants to select a different value for them.
