@@ -86,11 +86,7 @@ func NewZookeeperTreeCache(conn *zk.Conn, path string, events chan ZookeeperTree
 		children: map[string]*zookeeperTreeCacheNode{},
 		stopped:  true,
 	}
-	err := tc.recursiveNodeUpdate(path, tc.head)
-	if err != nil {
-		log.Errorf("Error during initial read of Zookeeper: %s", err)
-	}
-	go tc.loop(err != nil)
+	go tc.loop(path)
 	return tc
 }
 
@@ -98,7 +94,8 @@ func (tc *ZookeeperTreeCache) Stop() {
 	tc.stop <- struct{}{}
 }
 
-func (tc *ZookeeperTreeCache) loop(failureMode bool) {
+func (tc *ZookeeperTreeCache) loop(path string) {
+	failureMode := false
 	retryChan := make(chan struct{})
 
 	failure := func() {
@@ -108,7 +105,10 @@ func (tc *ZookeeperTreeCache) loop(failureMode bool) {
 			retryChan <- struct{}{}
 		})
 	}
-	if failureMode {
+
+	err := tc.recursiveNodeUpdate(path, tc.head)
+	if err != nil {
+		log.Errorf("Error during initial read of Zookeeper: %s", err)
 		failure()
 	}
 
@@ -168,7 +168,7 @@ func (tc *ZookeeperTreeCache) loop(failureMode bool) {
 				failureMode = false
 			}
 		case <-tc.stop:
-			close(tc.events)
+			tc.recursiveStop(tc.head)
 			return
 		}
 	}
@@ -264,3 +264,13 @@ func (tc *ZookeeperTreeCache) recursiveDelete(path string, node *zookeeperTreeCa
 		tc.recursiveDelete(path+"/"+name, childNode)
 	}
 }
+
+func (tc *ZookeeperTreeCache) recursiveStop(node *zookeeperTreeCacheNode) {
+	if !node.stopped {
+		node.done <- struct{}{}
+		node.stopped = true
+	}
+	for _, childNode := range node.children {
+		tc.recursiveStop(childNode)
+	}
+}
